@@ -12,17 +12,17 @@ To execute all Jupyter notebooks in a folder recursively:
 # Authors: Dr. Qiusheng Wu (https://wetlands.io)
 # License: MIT
 
-import os
-import glob
-import shutil
-import random
-import string
 import argparse
-import subprocess
+import glob
+import os
 import pkg_resources
+import random
+import shutil
+import string
+import subprocess
 import urllib.request
-from pathlib import Path
 from collections import deque
+from pathlib import Path
 
 
 def random_string(string_length=3):
@@ -341,7 +341,7 @@ def js_to_python(in_file, out_file=None, use_qgis=True, github_repo=None):
         with open(in_file) as f:
             lines = f.readlines()
 
-            print('Processing {}'.format(in_file))
+            # print('Processing {}'.format(in_file))
             lines = check_map_functions(lines)
 
             for index, line in enumerate(lines):
@@ -440,11 +440,15 @@ def js_to_python_dir(in_dir, out_dir=None, use_qgis=True, github_repo=None):
         github_repo (str, optional): GitHub repo url. Defaults to None.
 
     """
+    print('Converting Earth Engine JavaScripts to Python scripts...\n')
     if out_dir is None:
         out_dir = in_dir
 
-    for in_file in Path(in_dir).rglob('*.js'):
-        out_file = os.path.splitext(in_file)[0] + ".py"
+    files = list(Path(in_dir).rglob('*.js'))
+
+    for index, in_file in enumerate(files):
+        print('Processing {}/{}: {}'.format(index+1, len(files), in_file))
+        out_file = os.path.splitext(in_file)[0] + "_qgis.py"
         out_file = out_file.replace(in_dir, out_dir)
         js_to_python(in_file, out_file, use_qgis, github_repo)
     # print("Output Python script folder: {}".format(out_dir))
@@ -497,8 +501,8 @@ def get_js_examples(out_dir=None):
         str: The folder containing the JavaScript examples.
     """
     pkg_dir = os.path.dirname(pkg_resources.resource_filename("geemap", "geemap.py"))
-    example_dir = os.path.join(pkg_dir, 'examples')
-    js_dir = os.path.join(example_dir, 'JavaScripts')
+    example_dir = os.path.join(pkg_dir, 'data')
+    js_dir = os.path.join(example_dir, 'javascripts')
 
     files = list(Path(js_dir).rglob('*.js'))
     if out_dir is None:
@@ -526,8 +530,8 @@ def get_nb_template(download_latest=False, out_file=None):
         str: The file path of the template.
     """
     pkg_dir = os.path.dirname(pkg_resources.resource_filename("geemap", "geemap.py"))
-    example_dir = os.path.join(pkg_dir, 'examples')
-    template_dir = os.path.join(example_dir, 'Template')
+    example_dir = os.path.join(pkg_dir, 'data')
+    template_dir = os.path.join(example_dir, 'template')
     template_file = os.path.join(template_dir, 'template.py')
 
     if out_file is None:
@@ -541,7 +545,7 @@ def get_nb_template(download_latest=False, out_file=None):
         os.makedirs(os.path.dirname(out_file))
 
     if download_latest:
-        template_url = 'https://raw.githubusercontent.com/giswqs/geemap/master/geemap/examples/Template/template.py'
+        template_url = 'https://raw.githubusercontent.com/giswqs/geemap/master/examples/template/template.py'
         print("Downloading the latest notebook template from {}".format(template_url))
         urllib.request.urlretrieve(template_url, out_file)   
     elif out_file is not None:
@@ -609,8 +613,15 @@ def py_to_ipynb(in_file, template_file, out_file=None, github_username=None, git
         github_repo (str, optional): GitHub repo name. Defaults to None.
     """    
     if out_file is None:
-        out_file = in_file.replace('.py', '.ipynb')
-    out_py_file = in_file.replace(".py", "_nb.py")
+        out_file =  os.path.splitext(in_file)[0].replace('_qgis', '') + '.ipynb'
+
+    out_py_file = os.path.splitext(out_file)[0] + '.py'
+
+    out_dir = os.path.dirname(out_file)
+    if not os.path.exists(out_dir):
+        os.makedirs(out_dir)
+    if out_dir == os.path.dirname(in_file):
+        out_py_file = os.path.splitext(out_file)[0] + '.py'
 
     content = remove_qgis_import(in_file)
     header = template_header(template_file)
@@ -618,17 +629,17 @@ def py_to_ipynb(in_file, template_file, out_file=None, github_username=None, git
 
     if (github_username is not None) and (github_repo is not None):
 
-        out_py_path = str(in_file).split('/')
+        out_py_path = str(out_file).split('/')
         index = out_py_path.index(github_repo)
         out_py_relative_path = '/'.join(out_py_path[index+1:])
         out_ipynb_relative_path = out_py_relative_path.replace('.py', '.ipynb')
 
         new_header = []
-        for line in header:
-            line = line.replace('giswqs', github_username)
-            line = line.replace('earthengine-py-notebooks', github_repo)
-            line = line.replace('Template/template.ipynb', out_ipynb_relative_path)
-
+        for index, line in enumerate(header): 
+            if index < 10:  # Change Google Colab and binder URLs
+                line = line.replace('giswqs', github_username)
+                line = line.replace('geemap', github_repo)
+                line = line.replace('examples/template/template.ipynb', out_ipynb_relative_path)
             new_header.append(line)
         header = new_header
 
@@ -651,7 +662,7 @@ def py_to_ipynb(in_file, template_file, out_file=None, github_username=None, git
         print('Please install ipynb-py-convert using the following command:\n')
         print('pip install ipynb-py-convert')
 
-    os.remove(out_py_file)
+    # os.remove(out_py_file)
 
 
 def py_to_ipynb_dir(in_dir, template_file, out_dir=None, github_username=None, github_repo=None):
@@ -660,17 +671,30 @@ def py_to_ipynb_dir(in_dir, template_file, out_dir=None, github_username=None, g
     Args:
         in_dir (str): Input folder containing Earth Engine Python scripts.
         template_file (str): Input jupyter notebook template file.
-        out_dir str, optional): Ouput folder. Defaults to None.
+        out_dir str, optional): Output folder. Defaults to None.
         github_username (str, optional): GitHub username. Defaults to None.
         github_repo (str, optional): GitHub repo name. Defaults to None.
     """    
-    files = list(Path(in_dir).rglob('*.py'))
+    print('Converting Earth Engine Python scripts to Jupyter notebooks ...\n')
+
+    files = []
+    qgis_files = list(Path(in_dir).rglob('*_qgis.py'))
+    py_files = list(Path(in_dir).rglob('*.py'))
+
+    if len(qgis_files) == len(py_files) / 2:
+        files = qgis_files
+    else:
+        files = py_files
+
     if out_dir is None:
         out_dir = in_dir
+    elif not os.path.exists(out_dir):
+        os.makedirs(out_dir)
 
-    for file in files:
+    for index, file in enumerate(files):
         in_file = str(file)
-        out_file = in_file.replace(in_dir, out_dir).replace('.py', '.ipynb')
+        out_file = in_file.replace(in_dir, out_dir).replace('_qgis', '').replace('.py', '.ipynb')
+        print('Processing {}/{}: {}'.format(index+1, len(files), in_file))
         py_to_ipynb(in_file, template_file, out_file, github_username, github_repo)
 
 
@@ -691,6 +715,8 @@ def execute_notebook_dir(in_dir):
     Args:
         in_dir (str): Input folder containing notebooks.
     """
+    print('Executing Earth Engine Jupyter notebooks ...\n')
+
     files = list(Path(in_dir).rglob('*.ipynb'))
     count = len(files)
     if files is not None:
@@ -705,7 +731,7 @@ if __name__ == '__main__':
 
     # Create a temporary working directory
     work_dir = os.path.join(os.path.expanduser('~'), 'geemap')
-    # Get Earth Engine JavaScript examples. There are five examples in the geemap package folder. 
+    # Get Earth Engine JavaScript examples. There are five examples in the geemap package data folder. 
     # Change js_dir to your own folder containing your Earth Engine JavaScripts, such as js_dir = '/path/to/your/js/folder'
     js_dir = get_js_examples(out_dir=work_dir) 
 
